## Topsis-Sidharth-102003395
Topsis implementation in python. Used as a command line tool to generate topsis score and ranks of the given input data file along with weights and impacts.

## Installation
``` pip install Topsis-Sidharth-102003395```

## How to use it?
Open the terminal / cmd and type topsis <input_filename.csv> <"Weights"> <"Impacts"> <output_filename.csv>

## License
© 2023 Sidharth

This repository is licensed under the MIT license. See LICENSE for details.

